/*
 * libherdstat -- src/regex-test.cc
 * $Id: regex-test.cc 99 2005-11-02 14:00:42Z ka0ttic $
 * Copyright (c) 2005 Aaron Walker <ka0ttic@gentoo.org>
 *
 * This file is part of libherdstat.
 *
 * libherdstat is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * libherdstat is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * libherdstat; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 325, Boston, MA  02111-1257  USA
 */

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include <iostream>
#include <cstdlib>
#include <algorithm>
#include <functional>

#include <herdstat/exceptions.hh>
#include <herdstat/util/regex.hh>
#include <herdstat/util/functional.hh>

using namespace herdstat;

int main()
{
    try
    {
        std::cout << "Testing util::Regex:" << std::endl;

        const std::string word1("This is a test");
        const std::string word2("test a is This");

        const util::Regex regex("test$");

        std::cout << "'" << regex() << "' == '" << word1 << "' ? "
            << (regex == word1) << std::endl;
        std::cout << "'" << regex() << "' == '" << word2 << "' ? "
            << (regex == word2) << std::endl;

        std::cout << std::endl << "Testing util::regexMatch():" << std::endl;

        std::vector<std::string> v;
        v.push_back(word2);
        v.push_back(word1);
        v.push_back("test");

        std::vector<std::string>::iterator i =
            std::find_if(v.begin(), v.end(),
                std::bind1st(util::regexMatch(), regex));

        std::cout << "found '" << *i << "'." << std::endl;

        assert(*i == word1);
    }
    catch (const BaseException& e)
    {
        std::cerr << e.what() << std::endl;
        return EXIT_FAILURE;
    }

    return EXIT_SUCCESS;
}

/* vim: set tw=80 sw=4 et : */
